@@ -6,6 +6,7 @@ import (
 	"fmt"
 	"net/http"
 	"net/url"
+	"strings"
 	"time"
 
 	"github.com/cli/cli/v2/internal/ghrepo"
@@ -316,6 +317,9 @@ type RequestedReviewer struct {
 	} `json:"organization"`
 }
 
+const teamTypeName = "Team"
+const botTypeName = "Bot"
+
 func (r RequestedReviewer) LoginOrSlug() string {
 	if r.TypeName == teamTypeName {
 		return fmt.Sprintf("%s/%s", r.Organization.Login, r.Slug)
@@ -323,7 +327,21 @@ func (r RequestedReviewer) LoginOrSlug() string {
 	return r.Login
 }
 
-const teamTypeName = "Team"
+// DisplayName returns a user-friendly name for the reviewer.
+// For Copilot bot, returns "Copilot (AI)". For teams, returns "org/slug".
+// For users, returns "login (Name)" if name is available, otherwise just login.
+func (r RequestedReviewer) DisplayName() string {
+	if r.TypeName == teamTypeName {
+		return fmt.Sprintf("%s/%s", r.Organization.Login, r.Slug)
+	}
+	if r.TypeName == botTypeName && r.Login == CopilotReviewerLogin {
+		return "Copilot (AI)"
+	}
+	if r.Name != "" {
+		return fmt.Sprintf("%s (%s)", r.Login, r.Name)
+	}
+	return r.Login
+}
 
 func (r ReviewRequests) Logins() []string {
 	logins := make([]string, len(r.Nodes))
@@ -333,6 +351,15 @@ func (r ReviewRequests) Logins() []string {
 	return logins
 }
 
+// DisplayNames returns user-friendly display names for all requested reviewers.
+func (r ReviewRequests) DisplayNames() []string {
+	names := make([]string, len(r.Nodes))
+	for i, r := range r.Nodes {
+		names[i] = r.RequestedReviewer.DisplayName()
+	}
+	return names
+}
+
 func (pr PullRequest) HeadLabel() string {
 	if pr.IsCrossRepository {
 		return fmt.Sprintf("%s:%s", pr.HeadRepositoryOwner.Login, pr.HeadRefName)
@@ -631,7 +658,32 @@ func CreatePullRequest(client *Client, repo *Repository, params map[string]inter
 	return pr, nil
 }
 
+// extractTeamSlugs extracts just the slug portion from team identifiers.
+// Team identifiers can be in "org/slug" format; this returns just the slug.
+func extractTeamSlugs(teams []string) []string {
+	slugs := make([]string, 0, len(teams))
+	for _, t := range teams {
+		if t == "" {
+			continue
+		}
+		s := strings.SplitN(t, "/", 2)
+		slugs = append(slugs, s[len(s)-1])
+	}
+	return slugs
+}
+
+// toGitHubV4Strings converts a string slice to a githubv4.String slice,
+// optionally appending a suffix to each element.
+func toGitHubV4Strings(strs []string, suffix string) []githubv4.String {
+	result := make([]githubv4.String, len(strs))
+	for i, s := range strs {
+		result[i] = githubv4.String(s + suffix)
+	}
+	return result
+}
+
 // AddPullRequestReviews adds the given user and team reviewers to a pull request using the REST API.
+// Team identifiers can be in "org/slug" format.
 func AddPullRequestReviews(client *Client, repo ghrepo.Interface, prNumber int, users, teams []string) error {
 	if len(users) == 0 && len(teams) == 0 {
 		return nil
@@ -641,9 +693,6 @@ func AddPullRequestReviews(client *Client, repo ghrepo.Interface, prNumber int,
 	if users == nil {
 		users = []string{}
 	}
-	if teams == nil {
-		teams = []string{}
-	}
 
 	path := fmt.Sprintf(
 		"repos/%s/%s/pulls/%d/requested_reviewers",
@@ -656,7 +705,7 @@ func AddPullRequestReviews(client *Client, repo ghrepo.Interface, prNumber int,
 		TeamReviewers []string `json:"team_reviewers"`
 	}{
 		Reviewers:     users,
-		TeamReviewers: teams,
+		TeamReviewers: extractTeamSlugs(teams),
 	}
 	buf := &bytes.Buffer{}
 	if err := json.NewEncoder(buf).Encode(body); err != nil {
@@ -667,6 +716,7 @@ func AddPullRequestReviews(client *Client, repo ghrepo.Interface, prNumber int,
 }
 
 // RemovePullRequestReviews removes requested reviewers from a pull request using the REST API.
+// Team identifiers can be in "org/slug" format.
 func RemovePullRequestReviews(client *Client, repo ghrepo.Interface, prNumber int, users, teams []string) error {
 	if len(users) == 0 && len(teams) == 0 {
 		return nil
@@ -676,9 +726,6 @@ func RemovePullRequestReviews(client *Client, repo ghrepo.Interface, prNumber in
 	if users == nil {
 		users = []string{}
 	}
-	if teams == nil {
-		teams = []string{}
-	}
 
 	path := fmt.Sprintf(
 		"repos/%s/%s/pulls/%d/requested_reviewers",
@@ -691,7 +738,7 @@ func RemovePullRequestReviews(client *Client, repo ghrepo.Interface, prNumber in
 		TeamReviewers []string `json:"team_reviewers"`
 	}{
 		Reviewers:     users,
-		TeamReviewers: teams,
+		TeamReviewers: extractTeamSlugs(teams),
 	}
 	buf := &bytes.Buffer{}
 	if err := json.NewEncoder(buf).Encode(body); err != nil {
@@ -701,6 +748,363 @@ func RemovePullRequestReviews(client *Client, repo ghrepo.Interface, prNumber in
 	return client.REST(repo.RepoHost(), "DELETE", path, buf, nil)
 }
 
+// RequestReviewsByLogin sets requested reviewers on a pull request using the GraphQL mutation.
+// This mutation replaces existing reviewers with the provided set unless union is true.
+// Only available on github.com, not GHES.
+// Bot logins should include the [bot] suffix (e.g., "copilot-pull-request-reviewer[bot]").
+// Team slugs should be in the format "org/team-slug".
+// When union is false (replace mode), passing empty slices will remove all reviewers.
+func RequestReviewsByLogin(client *Client, repo ghrepo.Interface, prID string, userLogins, botLogins, teamSlugs []string, union bool) error {
+	// In union mode (additive), nothing to do if all lists are empty.
+	// In replace mode, we may still need to call the mutation to clear reviewers.
+	if union && len(userLogins) == 0 && len(botLogins) == 0 && len(teamSlugs) == 0 {
+		return nil
+	}
+
+	var mutation struct {
+		RequestReviewsByLogin struct {
+			ClientMutationId string `graphql:"clientMutationId"`
+		} `graphql:"requestReviewsByLogin(input: $input)"`
+	}
+
+	type RequestReviewsByLoginInput struct {
+		PullRequestID githubv4.ID        `json:"pullRequestId"`
+		UserLogins    *[]githubv4.String `json:"userLogins,omitempty"`
+		BotLogins     *[]githubv4.String `json:"botLogins,omitempty"`
+		TeamSlugs     *[]githubv4.String `json:"teamSlugs,omitempty"`
+		Union         githubv4.Boolean   `json:"union"`
+	}
+
+	input := RequestReviewsByLoginInput{
+		PullRequestID: githubv4.ID(prID),
+		Union:         githubv4.Boolean(union),
+	}
+
+	userLoginValues := toGitHubV4Strings(userLogins, "")
+	input.UserLogins = &userLoginValues
+
+	// Bot logins require the [bot] suffix for the mutation
+	botLoginValues := toGitHubV4Strings(botLogins, "[bot]")
+	input.BotLogins = &botLoginValues
+
+	teamSlugValues := toGitHubV4Strings(teamSlugs, "")
+	input.TeamSlugs = &teamSlugValues
+
+	variables := map[string]interface{}{
+		"input": input,
+	}
+
+	return client.Mutate(repo.RepoHost(), "RequestReviewsByLogin", &mutation, variables)
+}
+
+// SuggestedAssignableActors fetches up to 10 suggested actors for a specific assignable
+// (Issue or PullRequest) node ID. `assignableID` is the GraphQL node ID for the Issue/PR.
+// Returns the actors, the total count of available assignees in the repo, and an error.
+func SuggestedAssignableActors(client *Client, repo ghrepo.Interface, assignableID string, query string) ([]AssignableActor, int, error) {
+	type responseData struct {
+		Repository struct {
+			AssignableUsers struct {
+				TotalCount int
+			}
+		} `graphql:"repository(owner: $owner, name: $name)"`
+		Node struct {
+			Issue struct {
+				SuggestedActors struct {
+					Nodes []struct {
+						TypeName string `graphql:"__typename"`
+						User     struct {
+							ID    string
+							Login string
+							Name  string
+						} `graphql:"... on User"`
+						Bot struct {
+							ID    string
+							Login string
+						} `graphql:"... on Bot"`
+					}
+				} `graphql:"suggestedActors(first: 10, query: $query)"`
+			} `graphql:"... on Issue"`
+			PullRequest struct {
+				SuggestedActors struct {
+					Nodes []struct {
+						TypeName string `graphql:"__typename"`
+						User     struct {
+							ID    string
+							Login string
+							Name  string
+						} `graphql:"... on User"`
+						Bot struct {
+							ID    string
+							Login string
+						} `graphql:"... on Bot"`
+					}
+				} `graphql:"suggestedActors(first: 10, query: $query)"`
+			} `graphql:"... on PullRequest"`
+		} `graphql:"node(id: $id)"`
+	}
+
+	variables := map[string]interface{}{
+		"id":    githubv4.ID(assignableID),
+		"query": githubv4.String(query),
+		"owner": githubv4.String(repo.RepoOwner()),
+		"name":  githubv4.String(repo.RepoName()),
+	}
+
+	var result responseData
+	if err := client.Query(repo.RepoHost(), "SuggestedAssignableActors", &result, variables); err != nil {
+		return nil, 0, err
+	}
+
+	availableAssigneesCount := result.Repository.AssignableUsers.TotalCount
+
+	var nodes []struct {
+		TypeName string `graphql:"__typename"`
+		User     struct {
+			ID    string
+			Login string
+			Name  string
+		} `graphql:"... on User"`
+		Bot struct {
+			ID    string
+			Login string
+		} `graphql:"... on Bot"`
+	}
+
+	if result.Node.PullRequest.SuggestedActors.Nodes != nil {
+		nodes = result.Node.PullRequest.SuggestedActors.Nodes
+	} else if result.Node.Issue.SuggestedActors.Nodes != nil {
+		nodes = result.Node.Issue.SuggestedActors.Nodes
+	}
+
+	actors := make([]AssignableActor, 0, len(nodes))
+
+	for _, n := range nodes {
+		if n.TypeName == "User" && n.User.Login != "" {
+			actors = append(actors, AssignableUser{id: n.User.ID, login: n.User.Login, name: n.User.Name})
+		} else if n.TypeName == "Bot" && n.Bot.Login != "" {
+			actors = append(actors, AssignableBot{id: n.Bot.ID, login: n.Bot.Login})
+		}
+	}
+
+	return actors, availableAssigneesCount, nil
+}
+
+// ReviewerCandidate represents a potential reviewer for a pull request.
+// This can be a User, Bot, or Team.
+type ReviewerCandidate interface {
+	DisplayName() string
+	Login() string
+
+	sealedReviewerCandidate()
+}
+
+// ReviewerUser is a user who can review a pull request.
+type ReviewerUser struct {
+	AssignableUser
+}
+
+func NewReviewerUser(login, name string) ReviewerUser {
+	return ReviewerUser{
+		AssignableUser: NewAssignableUser("", login, name),
+	}
+}
+
+func (r ReviewerUser) sealedReviewerCandidate() {}
+
+// ReviewerBot is a bot who can review a pull request.
+type ReviewerBot struct {
+	AssignableBot
+}
+
+func NewReviewerBot(login string) ReviewerBot {
+	return ReviewerBot{
+		AssignableBot: NewAssignableBot("", login),
+	}
+}
+
+func (b ReviewerBot) DisplayName() string {
+	if b.login == CopilotReviewerLogin {
+		return fmt.Sprintf("%s (AI)", CopilotActorName)
+	}
+	return b.Login()
+}
+
+func (r ReviewerBot) sealedReviewerCandidate() {}
+
+// ReviewerTeam is a team that can review a pull request.
+type ReviewerTeam struct {
+	org      string
+	teamSlug string
+}
+
+// NewReviewerTeam creates a new ReviewerTeam.
+func NewReviewerTeam(orgName, teamSlug string) ReviewerTeam {
+	return ReviewerTeam{org: orgName, teamSlug: teamSlug}
+}
+
+func (r ReviewerTeam) DisplayName() string {
+	return fmt.Sprintf("%s/%s", r.org, r.teamSlug)
+}
+
+func (r ReviewerTeam) Login() string {
+	return fmt.Sprintf("%s/%s", r.org, r.teamSlug)
+}
+
+func (r ReviewerTeam) Slug() string {
+	return r.teamSlug
+}
+
+func (r ReviewerTeam) sealedReviewerCandidate() {}
+
+// SuggestedReviewerActors fetches suggested reviewers for a pull request.
+// It combines results from three sources using a cascading quota system:
+// - suggestedReviewerActors - suggested based on PR activity (base quota: 5)
+// - repository collaborators - all collaborators (base quota: 5 + unfilled from suggestions)
+// - organization teams - all teams for org repos (base quota: 5 + unfilled from collaborators)
+//
+// This ensures we show up to 15 total candidates, with each source filling any
+// unfilled quota from the previous source. Results are deduplicated.
+// Returns the candidates, a MoreResults count, and an error.
+func SuggestedReviewerActors(client *Client, repo ghrepo.Interface, prID string, query string) ([]ReviewerCandidate, int, error) {
+	// Fetch 10 from each source to allow cascading quota to fill from available results.
+	// Use a single query that includes organization.teams - if the owner is not an org,
+	// we'll get a "Could not resolve to an Organization" error which we handle gracefully.
+	// We also fetch unfiltered total counts via aliases for the "X more" display.
+	type responseData struct {
+		Node struct {
+			PullRequest struct {
+				SuggestedActors struct {
+					Nodes []struct {
+						IsAuthor    bool
+						IsCommenter bool
+						Reviewer    struct {
+							TypeName string `graphql:"__typename"`
+							User     struct {
+								Login string
+								Name  string
+							} `graphql:"... on User"`
+							Bot struct {
+								Login string
+							} `graphql:"... on Bot"`
+						}
+					}
+				} `graphql:"suggestedReviewerActors(first: 10, query: $query)"`
+			} `graphql:"... on PullRequest"`
+		} `graphql:"node(id: $id)"`
+		Repository struct {
+			Collaborators struct {
+				Nodes []struct {
+					Login string
+					Name  string
+				}
+			} `graphql:"collaborators(first: 10, query: $query)"`
+			CollaboratorsTotalCount struct {
+				TotalCount int
+			} `graphql:"collaboratorsTotalCount: collaborators(first: 0)"`
+		} `graphql:"repository(owner: $owner, name: $name)"`
+		Organization struct {
+			Teams struct {
+				Nodes []struct {
+					Slug string
+				}
+			} `graphql:"teams(first: 10, query: $query)"`
+			TeamsTotalCount struct {
+				TotalCount int
+			} `graphql:"teamsTotalCount: teams(first: 0)"`
+		} `graphql:"organization(login: $owner)"`
+	}
+
+	variables := map[string]interface{}{
+		"id":    githubv4.ID(prID),
+		"query": githubv4.String(query),
+		"owner": githubv4.String(repo.RepoOwner()),
+		"name":  githubv4.String(repo.RepoName()),
+	}
+
+	var result responseData
+	err := client.Query(repo.RepoHost(), "SuggestedReviewerActors", &result, variables)
+	// Handle the case where the owner is not an organization - the query still returns
+	// partial data (repository, node), so we can continue processing.
+	if err != nil && !strings.Contains(err.Error(), errorResolvingOrganization) {
+		return nil, 0, err
+	}
+
+	// Build candidates using cascading quota logic:
+	// Each source has a base quota of 5, plus any unfilled quota from previous sources.
+	// This ensures we show up to 15 total candidates, filling gaps when earlier sources have fewer.
+	seen := make(map[string]bool)
+	var candidates []ReviewerCandidate
+	const baseQuota = 5
+
+	// Suggested reviewers (excluding author)
+	suggestionsAdded := 0
+	for _, n := range result.Node.PullRequest.SuggestedActors.Nodes {
+		if suggestionsAdded >= baseQuota {
+			break
+		}
+		if n.IsAuthor {
+			continue
+		}
+		var candidate ReviewerCandidate
+		var login string
+		if n.Reviewer.TypeName == "User" && n.Reviewer.User.Login != "" {
+			login = n.Reviewer.User.Login
+			candidate = NewReviewerUser(login, n.Reviewer.User.Name)
+		} else if n.Reviewer.TypeName == "Bot" && n.Reviewer.Bot.Login != "" {
+			login = n.Reviewer.Bot.Login
+			candidate = NewReviewerBot(login)
+		} else {
+			continue
+		}
+		if !seen[login] {
+			seen[login] = true
+			candidates = append(candidates, candidate)
+			suggestionsAdded++
+		}
+	}
+
+	// Collaborators: quota = base + unfilled from suggestions
+	collaboratorsQuota := baseQuota + (baseQuota - suggestionsAdded)
+	collaboratorsAdded := 0
+	for _, c := range result.Repository.Collaborators.Nodes {
+		if collaboratorsAdded >= collaboratorsQuota {
+			break
+		}
+		if c.Login == "" {
+			continue
+		}
+		if !seen[c.Login] {
+			seen[c.Login] = true
+			candidates = append(candidates, NewReviewerUser(c.Login, c.Name))
+			collaboratorsAdded++
+		}
+	}
+
+	// Teams: quota = base + unfilled from collaborators
+	teamsQuota := baseQuota + (collaboratorsQuota - collaboratorsAdded)
+	teamsAdded := 0
+	ownerName := repo.RepoOwner()
+	for _, t := range result.Organization.Teams.Nodes {
+		if teamsAdded >= teamsQuota {
+			break
+		}
+		if t.Slug == "" {
+			continue
+		}
+		teamLogin := fmt.Sprintf("%s/%s", ownerName, t.Slug)
+		if !seen[teamLogin] {
+			seen[teamLogin] = true
+			candidates = append(candidates, NewReviewerTeam(ownerName, t.Slug))
+			teamsAdded++
+		}
+	}
+
+	// MoreResults uses unfiltered total counts (teams will be 0 for personal repos)
+	moreResults := result.Repository.CollaboratorsTotalCount.TotalCount + result.Organization.TeamsTotalCount.TotalCount
+
+	return candidates, moreResults, nil
+}
+
 func UpdatePullRequestBranch(client *Client, repo ghrepo.Interface, params githubv4.UpdatePullRequestBranchInput) error {
 	var mutation struct {
 		UpdatePullRequestBranch struct {
