@@ -5,6 +5,7 @@ import (
 	"net/http"
 
 	"github.com/cli/cli/v2/api"
+	fd "github.com/cli/cli/v2/internal/featuredetection"
 	"github.com/cli/cli/v2/internal/ghrepo"
 	prShared "github.com/cli/cli/v2/pkg/cmd/pr/shared"
 )
@@ -13,9 +14,9 @@ func shouldUseSearch(filters prShared.FilterOptions) bool {
 	return filters.Draft != nil || filters.Author != "" || filters.Assignee != "" || filters.Search != "" || len(filters.Labels) > 0
 }
 
-func listPullRequests(httpClient *http.Client, repo ghrepo.Interface, filters prShared.FilterOptions, limit int) (*api.PullRequestAndTotalCount, error) {
+func listPullRequests(httpClient *http.Client, detector fd.Detector, repo ghrepo.Interface, filters prShared.FilterOptions, limit int) (*api.PullRequestAndTotalCount, error) {
 	if shouldUseSearch(filters) {
-		return searchPullRequests(httpClient, repo, filters, limit)
+		return searchPullRequests(httpClient, detector, repo, filters, limit)
 	}
 
 	return prShared.NewLister(httpClient).List(prShared.ListOptions{
@@ -28,7 +29,16 @@ func listPullRequests(httpClient *http.Client, repo ghrepo.Interface, filters pr
 	})
 }
 
-func searchPullRequests(httpClient *http.Client, repo ghrepo.Interface, filters prShared.FilterOptions, limit int) (*api.PullRequestAndTotalCount, error) {
+func searchPullRequests(httpClient *http.Client, detector fd.Detector, repo ghrepo.Interface, filters prShared.FilterOptions, limit int) (*api.PullRequestAndTotalCount, error) {
+	// TODO advancedIssueSearchCleanup
+	// We won't need feature detection when GHES 3.17 support ends, since
+	// the advanced issue search is the only available search backend for
+	// issues.
+	features, err := detector.SearchFeatures()
+	if err != nil {
+		return nil, err
+	}
+
 	type response struct {
 		Search struct {
 			Nodes    []api.PullRequest
@@ -44,10 +54,11 @@ func searchPullRequests(httpClient *http.Client, repo ghrepo.Interface, filters
 	query := fragment + `
 		query PullRequestSearch(
 			$q: String!,
+			$type: SearchType!,
 			$limit: Int!,
 			$endCursor: String,
 		) {
-			search(query: $q, type: ISSUE, first: $limit, after: $endCursor) {
+			search(query: $q, type: $type, first: $limit, after: $endCursor) {
 				issueCount
 				nodes {
 					...pr
@@ -59,12 +70,26 @@ func searchPullRequests(httpClient *http.Client, repo ghrepo.Interface, filters
 			}
 		}`
 
+	variables := map[string]interface{}{}
+
 	filters.Repo = ghrepo.FullName(repo)
 	filters.Entity = "pr"
-	q := prShared.SearchQueryBuild(filters)
+
+	// TODO advancedIssueSearchCleanup
+	if features.AdvancedIssueSearchAPI {
+		variables["q"] = prShared.SearchQueryBuild(filters, true)
+		// TODO advancedIssueSearchCleanup
+		if features.AdvancedIssueSearchAPIOptIn {
+			variables["type"] = "ISSUE_ADVANCED"
+		} else {
+			variables["type"] = "ISSUE"
+		}
+	} else {
+		variables["q"] = prShared.SearchQueryBuild(filters, false)
+		variables["type"] = "ISSUE"
+	}
 
 	pageLimit := min(limit, 100)
-	variables := map[string]interface{}{"q": q}
 
 	res := api.PullRequestAndTotalCount{SearchCapped: limit > 1000}
 	var check = make(map[int]struct{})
